@@ -26,3 +26,16 @@ class Comment(Base):
         self.created = node.get("createdAt")
         self.updatedAt = node.get("updatedAt")
         self.author = User(node.get("author"))
+
+    def delete(self):
+        """Delete the comment"""
+
+        query = """
+        mutation deleteComment($id: ID!) {
+            deleteIssueComment(input: {id: $id}) {
+                clientMutationId
+            }
+        }
+        """
+        data = {"id": self.id}
+        self.run_query(query, data)
